<#
.Description
    Powershell script progettato per cercare una stringa specificata dall'utente in un insieme di file di testo all'interno di una directory e sottodirectory specifiche. Una volta trovata la stringa, offre all'utente la possibilità di sostituirla con un'altra stringa.
.Author 
    Roberto Bonfa'
.Version
    1.5
#>

<#
.Description
    Questo script è utilizzato per ricercare e modificare un parametro in file di testo.
.Author 
    Roberto Bonfa'
.Version
    1.5
#>

function Search-ParameterInFiles {
    param (
        [string]$path,
        [string]$parameter
    )
    Get-ChildItem -Path $path -Include "*.txt" -Recurse | ForEach-Object {
        $file = $_
        $content = Get-Content $file.FullName
        $count = ($content | Select-String $parameter).Count
        if ($count -gt 0) {
            [PSCustomObject]@{
                File  = $file.FullName
                Count = $count
            }
        }
    }
}

function Replace-ParameterInFiles {
    param (
        [string[]]$files,
        [string]$oldParameter,
        [string]$newParameter
    )
    foreach ($file in $files) {
        try {
            (Get-Content $file) | Foreach-Object {$_ -replace $oldParameter, $newParameter} | Set-Content $file
            Write-Host "File modified: $file"
        } catch {
            Write-Host "Error modifying file $file: $_"
        }
    }
}

$parameter = Read-Host "Enter the parameter you want to search for"
$searchPath = "C:\example\path\to\files"

$results = Search-ParameterInFiles -path $searchPath -parameter $parameter
$results | Format-Table -AutoSize

$change = Read-Host "Do you want to change this parameter? (y/n)"

if ($change -eq "y") {
    $newParameter = Read-Host "Enter the new parameter"
    $filesToChange = Read-Host "Enter the file(s) you want to change (separate by comma)"
    $filesToChange = $filesToChange -split ","

    # Validate and trim file paths
    $validFilesToChange = $filesToChange | Where-Object {Test-Path $_} | ForEach-Object {$_.Trim()}

    Replace-ParameterInFiles -files $validFilesToChange -oldParameter $parameter -newParameter $newParameter
}